==> haskell-monad-par-0.3.4.8-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par
version: 0.3.4.8
id: monad-par-0.3.4.8-Dxa8J3AG2Sg6WOpLXj8L09
key: monad-par-0.3.4.8-Dxa8J3AG2Sg6WOpLXj8L09
license: BSD3
copyright: (c) Simon Marlow 2011
maintainer: Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.
    .
    For complete documentation see "Control.Monad.Par".
    .
    Some examples of use can be found in the @examples/@ directory of
    the source package.
    .
    Other related packages:
    .
    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.
    .
    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.
    .
    Changes in 0.3.4 relative to 0.3:
    .
    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.
    .
    * Added "Control.Monad.Par.IO"
category: Control,Parallelism,Monads
author: Simon Marlow, Ryan Newton
exposed: True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
hidden-modules: Control.Monad.Par.Scheds.DirectInternal
abi: da6de2b66f2c6c5f1ec5b3f51e1c3e30
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-par-0.3.4.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-par-0.3.4.8
data-dir: /usr/share/arm-linux-ghc-8.0.1/monad-par-0.3.4.8
hs-libraries: HSmonad-par-0.3.4.8-Dxa8J3AG2Sg6WOpLXj8L09
depends:
    abstract-deque-0.3-3xNrV1OHLKZHwGiIECHG3h
    abstract-par-0.3.3-I2gvKCBAweu3uYwWNazPJ0 array-0.5.1.1
    base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    monad-par-extras-0.3.3-4NSJC48GnVF68j1ZuIgmiE
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.4.0-CH6ozsPFZjwVSNwmEz44J
    parallel-3.2.1.0-6VcN0yUHtcs831TgbJiSSi
haddock-interfaces: /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html: /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-0.3.4.8-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par
version: 0.3.4.8
id: monad-par-0.3.4.8-ApJPC8xw7BWHZa5E5qImpQ
key: monad-par-0.3.4.8-ApJPC8xw7BWHZa5E5qImpQ
license: BSD3
copyright: (c) Simon Marlow 2011
maintainer: Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.
    .
    For complete documentation see "Control.Monad.Par".
    .
    Some examples of use can be found in the @examples/@ directory of
    the source package.
    .
    Other related packages:
    .
    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.
    .
    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.
    .
    Changes in 0.3.4 relative to 0.3:
    .
    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.
    .
    * Added "Control.Monad.Par.IO"
category: Control,Parallelism,Monads
author: Simon Marlow, Ryan Newton
exposed: True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
hidden-modules: Control.Monad.Par.Scheds.DirectInternal
abi: 43d8809b57b4b0cec58c26c3e38ffa38
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-par-0.3.4.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-par-0.3.4.8
data-dir: /usr/share/arm-linux-ghc-8.0.1/monad-par-0.3.4.8
hs-libraries: HSmonad-par-0.3.4.8-ApJPC8xw7BWHZa5E5qImpQ
depends:
    abstract-deque-0.3-3xNrV1OHLKZHwGiIECHG3h
    abstract-par-0.3.3-I2gvKCBAweu3uYwWNazPJ0 array-0.5.1.1
    base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    monad-par-extras-0.3.3-2svNFDzBzS82vbxGx9eHQm
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.4.0-CH6ozsPFZjwVSNwmEz44J
    parallel-3.2.1.0-6VcN0yUHtcs831TgbJiSSi
haddock-interfaces: /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html: /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
